@@ -8,12 +8,11 @@
 #include "../config.h"
 #endif
 /*
- * Initilize application's data structure
+ * Initialize application's data structure
  */
 app_data_t* app_init() {
     app_data_t *myapp;
 	const gchar *myrawext[] = {"PEF","pef","DNG","dng","NEF","nef","ARW","arw","CR2","cr2","CRW","crw","RAF","raf","DCR","dcr","MRW","mrw","ORF","orf","SRF","srf","SR2","sr2","MOS","mos","TIF","tif",NULL};
-	guint i;
 
 	myapp = g_new(app_data_t,1);
     /* Initialize application's data structure */
@@ -26,10 +25,7 @@ app_data_t* app_init() {
     myapp->imgparamwin = NULL;
     myapp->prevarrowbut = NULL;
     myapp->nextarrowbut = NULL;
-    myapp->rawext = g_malloc(sizeof(myrawext));
-	for(i = 0;myrawext[i] != NULL;i++) {
-		myapp->rawext[i] = g_strdup(myrawext[i]);
-	}
+    myapp->rawext = g_strdupv((gchar **)myrawext);
     myapp->zoomlevel = FIT_SCREEN;
     myapp->showimgparam = FALSE;
 
@@ -50,9 +46,6 @@ app_data_t* app_init() {
  * Free application data structure's allocated memory
  */
 void app_free(app_data_t *myapp) {
-	guint i;
-
-	for(i = 0;myapp->rawext[i] != NULL;i++) g_free(myapp->rawext[i]);
-    g_free(myapp->rawext);
+	g_strfreev(myapp->rawext);
     g_free(myapp);
 }
