@@ -46,7 +46,7 @@ void load_image(app_data_t *myapp, gchar *imgfname) {
 	gboolean imgerr = FALSE, imgthumb = TRUE;
 	gint shutternum = 0;
 	gchar *shutter = NULL;
-	const gchar *paramformat = "<span size=\"medium\" face=\"arial\">Filename: <b>%s</b>\nCamera model: <b>%s %s</b>\nShutter speed: <b>%s s</b>\nAperture: <b>f/%-.1f</b>\nISO: <b>%-.0f</b>\nFocal length: <b>%-.0f mm</b></span>";
+	const gchar *paramformat = "<span size=\"medium\" face=\"sans\">Filename: <b>%s</b>\nCamera model: <b>%s %s</b>\nShutter speed: <b>%s s</b>\nAperture: <b>f/%-.1f</b>\nISO: <b>%-.0f</b>\nFocal length: <b>%-.0f mm</b></span>";
 	GError *error = NULL;
 
 	g_free(myapp->currfname);
@@ -295,6 +295,7 @@ void ungrab_volume_keys(GtkWidget *widget) {
     unsigned long val = 1; /* ungrab, use 0 to grab */
     Atom atom;
     GdkDisplay *display = NULL;
+
     display = gtk_widget_get_display(widget);
     atom = gdk_x11_get_xatom_by_name_for_display(display,"_HILDON_ZOOM_KEY_ATOM");
     XChangeProperty (GDK_DISPLAY_XDISPLAY (display),
@@ -302,6 +303,22 @@ void ungrab_volume_keys(GtkWidget *widget) {
                      PropModeReplace,(unsigned char *)&val,1);
 }
 
+/*
+ * Force window compositing to remain enabled
+ */
+void window_force_compositing(GtkWidget *widget) {
+	int zero = 0;
+	Atom atom;
+    GdkDisplay *display = NULL;
+
+    display = gtk_widget_get_display(widget);
+    /* atom = XInternAtom(display,"_HILDON_NON_COMPOSITED_WINDOW",False); */
+    atom = gdk_x11_get_xatom_by_name_for_display(display,"_HILDON_NON_COMPOSITED_WINDOW");
+    XChangeProperty(GDK_DISPLAY_XDISPLAY (display),
+				    GDK_WINDOW_XID (GDK_WINDOW (widget->window)),atom,XA_INTEGER,32,
+					PropModeReplace,(unsigned char *)&zero,1);
+}
+
 /*
  * Store configuration values into GConf
  */
