@@ -62,7 +62,7 @@ void create_app(app_data_t *myapp) {
     hildon_program_add_window(myapp->app, myapp->mainwin);
 
     /* Create the main menu */
-    appmenu = HILDON_APP_MENU(hildon_app_menu_new());
+    appmenu = HILDON_APP_MENU (hildon_app_menu_new());
 
 	/* Add menu buttons */
     openitem = gtk_button_new_with_label("Open image");
@@ -126,6 +126,9 @@ void create_app(app_data_t *myapp) {
     /* Ungrab volume keys */
     ungrab_volume_keys(GTK_WIDGET (myapp->mainwin));
 
+    /* Force window compositing to remain enabled */
+    window_force_compositing(GTK_WIDGET (myapp->mainwin));
+
     /* Connect some signals */
     g_signal_connect(G_OBJECT (myapp->mainwin),"destroy",
     		G_CALLBACK (destroy_app),myapp);
